# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.8.0] - 2020-01-19
### Added
- Add getters to DirEntry.

### Changed
- Update documentation.

### Fixed
- Correctly count hardlinks.
- Update jwalk to get correct extended metadata (size and hardlinks).
  https://github.com/brmmm3/jwalk/tree/jwalk-0.4.1-alpha.1

## [0.7.2] - 2020-01-10
### Changed
- Change default iter_type for Walk to ITER_TYPE_WALK.

## [0.7.1] - 2020-01-10
### Changed
- Update documentation.

## [0.7.0] - 2020-01-09
- First release.
